@@ -1,12 +1,12 @@
 package WordList::ID::Common::Wikipedia5000;
 
 our $DATE = '2018-01-01'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
-our %STATS = ("num_words_contains_unicode",0,"avg_word_len",7.4514,"longest_word_len",18,"num_words_contains_whitespace",0,"shortest_word_len",2,"num_words_contains_nonword_chars",0,"num_words",5000); # STATS
+our %STATS = ("avg_word_len",7.4528,"num_words_contains_nonword_chars",0,"num_words_contains_whitespace",0,"num_words_contains_unicode",0,"shortest_word_len",2,"longest_word_len",18,"num_words",5000); # STATS
 
 1;
 # ABSTRACT: Top 5000 words from Wikipedia Indonesia pages
@@ -21,7 +21,7 @@ WordList::ID::Common::Wikipedia5000 - Top 5000 words from Wikipedia Indonesia pa
 
 =head1 VERSION
 
-This document describes version 0.003 of WordList::ID::Common::Wikipedia5000 (from Perl distribution WordLists-ID-Common), released on 2018-01-01.
+This document describes version 0.004 of WordList::ID::Common::Wikipedia5000 (from Perl distribution WordLists-ID-Common), released on 2018-01-01.
 
 =head1 SYNOPSIS
 
@@ -74,7 +74,7 @@ C<work/> directories in the Git repository.
  +----------------------------------+--------+
  | key                              | value  |
  +----------------------------------+--------+
- | avg_word_len                     | 7.4514 |
+ | avg_word_len                     | 7.4528 |
  | longest_word_len                 | 18     |
  | num_words                        | 5000   |
  | num_words_contains_nonword_chars | 0      |
@@ -115,7 +115,6 @@ the same terms as the Perl 5 programming language system itself.
 =cut
 
 __DATA__
-Islam
 abad
 abadi
 abjad
@@ -4803,6 +4802,7 @@ terdapat
 terdekat
 terdengar
 terdiri
+tereliminasi
 terendah
 tergabung
 terganggu
